%%
%% Author: Michal Houda
%% E-mail: houda at ef dot jcu dot cz
%%
%% Modified by: Stanislav Tvrz
%% E-mail: tvrz at mail dot muni dot cz
%%
%% Modified by: Miroslav Vavrousek
%% E-mail: miroslav dot vavrousek at tul dot cz
%% 
%% Noobishly modified by: Miroslav Rada
%% E-mail: miroslav dot rada at vse dot cz
%% Edited lines or blocks commented by ``MR''.
%% The main aim of the changes was to make all similar to MS Word 
%% template with no excesive pain. 
%%
%% Description: this is a LaTeX class for contributions to the 
%%   Proceedings of the International Conference on 
%%   Mathematical Methods in Economics
%% 
%% This program may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.2
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.2 or later is part of all distributions of LaTeX
%% version 1999/12/01 or later.
%% 
\NeedsTeXFormat{LaTeX2e}[1996/12/01]
\ProvidesClass{mmeproc_times}
  [2016/07/11 v1.11 MME Proceedings class for LaTeX 2e, itended for MME 2016]

%\p@=1pt             % MR: use pt in most cases instead of pt

%% Using article class, no additional options allowed
%%
\LoadClass[10pt,a4paper]{article}


%% Some preloaded packages
\RequirePackage{geometry}       % page dimensions
\RequirePackage{graphicx}       % including graphic files
\RequirePackage{amsmath,amsthm,amssymb}  % advanced mathematics
\RequirePackage{enumitem}       % modified enumerate environment
\RequirePackage[hang,flushmargin]{footmisc} % MR: footnotes without indentation
\RequirePackage{times}                      % MR: self-explanatory
\RequirePackage{anyfontsize}                % MR: arbitrary font size in sections
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                    PAGE DIMENSIONS AND FORMATTING                     %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% (2.5cm margins on both sides regardless of the paper size)
%%
\geometry{%
  a4paper,twoside,
  top=25mm,headsep=17pt,  
  bottom=25mm,footskip=13.5mm,
  left=25mm, % inner margin
  right=25mm % outer margin
}
\parskip=6pt %plus 1pt   % MR: commented plus part to fix parskip
\raggedbottom            % MR: no stretching, as in MS Word. It's ugly, but the Word template does it so.
\linespread{0.957}       % MR: similar linespread as in Rord template

% MR: several settings regarding enumerations
\setlist{topsep=0pt,noitemsep,align=left,labelwidth=15pt,labelsep=0pt,leftmargin=15pt,before={\parskip=0pt},after=\vspace*{\parskip}}
\setlist[itemize,2]{label=\textbullet}
\setlist[enumerate,2]{label=\alph*)}

% MR: bibsep definition
\RequirePackage[numbers]{natbib}                % MR: for bibsep and for other stuff.
\bibsep=2pt

% MR: footnotesize redefined to have same font size as normal text (yes, it looks ugly, but the MS Word template...)
\renewcommand\footnotesize{%
   \@setfontsize\footnotesize\@xpt\@xiipt
   \abovedisplayskip 10\p@ \@plus2\p@ \@minus5\p@
   \abovedisplayshortskip \z@ \@plus3\p@
   \belowdisplayshortskip 6\p@ \@plus3\p@ \@minus3\p@
   \belowdisplayskip \abovedisplayskip
   \let\@listi\@listI}

%%
%% Page numbering
%% The command \startpageno sets the page number to the specified value
%%
%\newcommand\startpageno[1]{\c@page=#1}
%% but this will be used only in production version of the proceedings
\pagestyle{empty}

%%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                             TITLE PAGE                                %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%
\def\cleartitleinfo{\gdef\@author{No Author Given}%
                   \gdef\@title{No Title Given}%
                   \gdef\@institute{No Institute Given}%
                   \gdef\@thanks{}%
                   \gdef\@keywords{No Keyword Given}%
                   \gdef\@amssubjclass{}%
                   \gdef\@jelsubjclass{}%
}
\AtBeginDocument{\cleartitleinfo}
%%
%% Author information
%%
\def\mmeproc@authors{
  \vspace*{-1.5pt}%             % MR: commented out as requested by MME 2016 organizators
  {\def\and{\mmeproc@and@author}
    \large \@author\footnote{%
      \@institute
      \if:\@email:\else, \@email\fi
    }\vskip 2pt%                % MR: modified spacing
}}
\def\mmeproc@and@author{%     % Author name is here already typeset, 
  \footnote{%
    {\@institute\if:\@email:\else, \@email\fi}\relax
  },
}%   % the next author

%%
%% Other titlepage information
%%
\def\email#1{\gdef\@email{#1}}
\def\institute#1{\gdef\@institute{#1}}%
\def\keywords#1{\gdef\@keywords{#1}}%
\def\amssubjclass#1{\gdef\@amssubjclass{%
  \textbf{AMS classification:} #1}}%
\def\jelsubjclass#1{\gdef\@jelsubjclass{%
  \textbf{JEL classification:} #1}}%
%%
%% Changes to the original LaTeX abstract environment
%% This does not work with the titlepage and twocolumn options!
%%
\newbox\mmeproc@abstractbox
\renewenvironment{abstract}{%
  \ifx\maketitle\relax
    \ClassWarning{mmeproc}{Abstract should precede
      \protect\maketitle\space in mmeproc class}%
  \fi
  \global\setbox\mmeproc@abstractbox=\hbox to 12cm
  \bgroup\begin{minipage}{12cm}\parskip=0pt   % MR modified \parskip
  \textbf{\abstractname.}
}{\end{minipage}\egroup}
%%
%% Making titlepage
%%

%%%% MR: command maketitle from article class, 
\def\maketitle{%\par% MR: commented out
  \begingroup
    %%% MR: custom footnote handling commented out
    %\renewcommand\thefootnote{\@fnsymbol\c@footnote}%
    %\def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
    %\long\def\@makefntext##1{\parindent 1em\noindent
            %\hb@xt@1.8em{%
                %\hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
    \if@twocolumn
      \ifnum \col@number=\@ne
        \@maketitle
      \else
        \twocolumn[\@maketitle]%
      \fi
    \else
      %\newpage%
      \global\@topnum\z@%   % Prevents figures from going at top of page.
      \@maketitle%
    \fi
    \thispagestyle{empty}\@thanks
  \endgroup
  %\setcounter{footnote}{0}%             % MR: commented out for continuously numbered footnotes
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}
%%%% MR: end of inserted maketitle

\def\@maketitle{%
  %\def\thefootnote{\@arabic\c@footnote}        % MR: no longer necessary provided that behaviour of \maketitle is redefined
  %\newpage%
  \vspace*{-19.5pt}   % MR: was 2em
  \begin{center}
    {\LARGE\bfseries \@title \par}%
    \mmeproc@authors\par
    \begin{minipage}{12cm}
      \parindent=\z@\parskip=6pt
      \box\mmeproc@abstractbox\par
      \vspace*{4pt}

    {\bfseries\noindent Keywords:} \@keywords\par
    \@jelsubjclass\parskip\z@\par
    \@amssubjclass\par
    \end{minipage}
  \end{center}
\pagestyle{empty}
}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                           HEADINGS                                    %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% only section and subsections are numbered within an article
%%
\setcounter{secnumdepth}{2}
%%
%% spacing shifted section <- subsection <- subsubsection
%%
\renewcommand\section{\@startsection {section}{1}{\z@}%
                                   {-6pt plus 0pt minus 0pt}% MR: fixed spacing before %{-3.25ex \@plus -1ex \@minus -.2ex}%
                                    {1pt plus 0pt minus 0pt}% MR: fixed spacing after % 1.5ex \@plus.2ex}%
                                  {\normalfont\fontsize{14pt}{15.4pt}\selectfont\bfseries}}% MR: was \large instead of \fontsize{}{}\selectfont}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
  {-6pt plus 0pt minus 0pt}%{-3.25ex\@plus -1ex \@minus -.2ex}%
  {0.5pt plus 0pt minus 0pt}%{1.5ex \@plus .2ex}%
                                   {\normalfont\fontsize{12pt}{13.2pt}\large\bfseries}}% MR: was \normalsize instead of \fontsize{}{}\selectfont}
% MR: Redefinition of \subsubsection with fixed spacing
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                  {-6pt \@plus 0pt \@minus 0pt}
                                  {0.3pt \@plus 0pt \@minus 0pt}
                                   {\normalfont\normalsize\bfseries}}
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                              LISTS                                    %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%  Modified enumerate and itemize environments

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                             THEOREMS                                  %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Theorems are defined using amsthm style file. 
%%
%
\theoremstyle{plain}
\newtheorem{theorem}{Theorem}
\newtheorem{proposition}[theorem]{Proposition}
%
\theoremstyle{definition}
\newtheorem{definition}{Definition}
\newtheorem{example}{Example}
\newtheorem{remark}{Remark}
%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                             OTHER                                     %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Table stretching
\renewcommand\arraystretch{1.2}
%%
%% Caption style modification (bold caption headers).
%%
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{{\bf #1} #2}%
  \ifdim \wd\@tempboxa >\hsize
    #1 #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}
%%
%%
%%
%% Environment article: setting starting page number
%% only for the production version of the proceedings
%%
\newenvironment{article}[1][1]{%
  \startpageno{#1}         % the starting page number
  \maketitle
}{\relax}
\def\acknowledgements{\section*{Acknowledgements}}
%%
%% modification of \@makecol (see original version in latex.ltx) 
%% -- the footnote is `vfilled'
%%
\gdef \@makecol {%
   \ifvoid\footins
     \setbox\@outputbox \box\@cclv
   \else
     \setbox\@outputbox \vbox {%
       \boxmaxdepth \@maxdepth
       \@tempdima\dp\@cclv
       \unvbox \@cclv
       \vskip-\@tempdima
       \vskip \skip\footins
       \vfill                   % <<--------- inserted
       \color@begingroup
         \normalcolor
         \footnoterule
         \unvbox \footins
       \color@endgroup
       }%
   \fi
   \xdef\@freelist{\@freelist\@midlist}%
   \global \let \@midlist \@empty
   \@combinefloats
   \ifvbox\@kludgeins
     \@makespecialcolbox
   \else
     \setbox\@outputbox \vbox to\@colht {%
       \@texttop
       \dimen@ \dp\@outputbox
       \unvbox \@outputbox
       \vskip -\dimen@
       \@textbottom
       }%
   \fi
   \global \maxdepth \@maxdepth
}

% MR: footnote rule width 
\renewcommand{\footnoterule}{%
  \kern -3pt
  \hrule width 14.25em 
  \kern 2.6pt
}

\endinput
%%
%% End of file `mmeproc.cls'.
